# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-19 15:01:40
@LastEditTime: 2025-01-10 17:29:51
@LastEditors: HuangJianYi
@Description: 
"""

#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class StoreBaseModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', db_config_dict=None, sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(StoreBaseModel, self).__init__(StoreBase, sub_table)
        if not db_config_dict:
            db_config_dict = config.get_value(db_connect_key)
        self.db = MySQLHelper(self.convert_db_config(db_config_dict, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class StoreBase:

    def __init__(self):
        super(StoreBase, self).__init__()
        self.id = 0  # id
        self.guid = None  # guid
        self.business_id = 0  # 商家标识
        self.scheme_id = 0 # 体系标识
        self.platform_id = 0  # 平台标识
        self.store_name = ""  # 店铺名称
        self.seller_nick = ""  # 店铺主账号
        self.plat_store_id = ""  # 平台店铺标识
        self.init_integral_multiple = ""  # 初始积分倍数
        self.init_growth_config = {}  # 初始成长值配置
        self.incr_process_start_date = "1970-01-01 00:00:00.000"  # 增量处理时间
        self.is_omid_merge = 0 # 是否走omid合并逻辑(1-是 0-否)
        self.create_date = "1970-01-01 00:00:00.000"  # 创建时间
        self.modify_date = "1970-01-01 00:00:00.000"  # 修改时间


    @classmethod
    def get_field_list(self):
        return ['id', 'guid', 'business_id', 'scheme_id', 'platform_id', 'store_name', 'seller_nick', 'plat_store_id', 'init_integral_multiple', 'init_growth_config', 'incr_process_start_date', 'is_omid_merge', 'create_date', 'modify_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "store_base_tb"



from datetime import timedelta
from seven_cloudapp_frame.libs.common import *
from seven_cloudapp_frame.libs.customize.seven_helper import *
from hk_cdp.models.db_models.queue.queue_work_log_model import *

class WorkBaseModel():
    """
    :description: 队列作业日志业务模型
    """

    def __init__(self, context=None, logging_error=None, logging_info=None, db_config_dict=None, sub_table=None):
        self.context = context
        self.logging_link_error = logging_error
        self.logging_link_info = logging_info
        self.db_config_dict = db_config_dict
        self.sub_table = sub_table

    def add_queue_work_log(self, log_id, queue_name, queue_value, is_success=1, result_info='执行成功'):
        """
        :description: 添加队列日志
        :param log_id：日志标识
        :param queue_name：队列名称
        :param queue_value：队列值
        :param is_success：是否成功 1-是 0-否
        :param result_info：结果信息
        :return: 
        :last_editors: HuangJianYi
        """
        try:
            queue_work_log_model = QueueWorkLogModel(db_config_dict=self.db_config_dict, sub_table=self.sub_table, context=self.context)
            queue_work_log = QueueWorkLog()
            queue_work_log.log_id = log_id
            queue_work_log.queue_name = queue_name
            queue_work_log.queue_value = queue_value
            queue_work_log.is_success = is_success
            queue_work_log.result_info = result_info
            queue_work_log.create_date = TimeHelper.get_now_format_time()
            queue_work_log_model.add_entity(queue_work_log)
        except Exception as ex:
            if self.context:
                self.context.logging_link_error("【添加队列日志】" + traceback.format_exc())
            elif self.logging_link_error:
                self.logging_link_error("【添加队列日志】" + traceback.format_exc())



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-11-22 17:23:58
@LastEditTime: 2024-12-31 11:27:01
@LastEditors: HuangJianYi
@Description: 
"""
__all__ = ["analysis_report_model", "analysis_goods_related_model", "analysis_goods_repurchase_model"]



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2025-01-09 17:57:48
@LastEditTime: 2025-02-12 09:55:34
@LastEditors: HuangJianYi
@Description: 
"""
class ListKey():
    """
    @description: 队列key
    """
    @classmethod
    def tt_history_member_list(self, store_id, is_check = False):
        """
        :description: 抖音历史会员队列（每个抖音店铺，第一次对接的时候使用一次性同步历史会员数据）
        :param store_id: 店铺标识
        :param is_check: is_check
        :return str
        :last_editors: HuangJianYi
        """
        prefix = "tt_history_member_list"
        if is_check == True:
            return f"{prefix}:check:{store_id}"
        return f"{prefix}:{store_id}"
    

    @classmethod
    def member_merge_list(self, merge_type, store_id, is_check = False):
        """
        :description: one_id合并队列
        :param merge_type: 合并类型，'omid' 或 'telephone'
        :param store_id: 店铺标识
        :param is_check: is_check
        :return str
        :last_editors: HuangJianYi
        """
        prefix = f"member_{merge_type}_merge_list"
        if is_check == True:
            return f"{prefix}:check:{store_id}"
        return f"{prefix}:{store_id}"
    

    @classmethod
    def register_member_list(self, store_id, is_check = False):
        """
        :description: 注册会员进行初始化计算队列
        :param store_id: 店铺标识
        :param is_check: is_check
        :return str
        :last_editors: HuangJianYi
        """
        prefix = "register_member_list"
        if is_check == True:
            return f"{prefix}:check:{store_id}"
        return f"{prefix}:{store_id}"
    
    
    @classmethod
    def history_member_settle_list(self, store_id, is_check = False):
        """
        :description: 注册会员进行初始化计算队列
        :param store_id: 店铺标识
        :param is_check: is_check
        :return str
        :last_editors: HuangJianYi
        """
        prefix = "history_member_settle_list"
        if is_check == True:
            return f"{prefix}:check:{store_id}"
        return f"{prefix}:{store_id}"

   
    @classmethod
    def member_mask_telephone_list(self, business_id, is_check = False):
        """
        :description: 掩码手机号处理队列（通过其他平台的手机码去抖音匹配，让抖音的会员得到真实的手机号）
        :param business_id: 商家标识
        :param is_check: is_check
        :return str
        :last_editors: HuangJianYi
        """
        prefix = "member_mask_telephone_list"
        if is_check == True:
            return f"{prefix}:check:businessid_{business_id}"
        return f"{prefix}:businessid_{business_id}"


    @classmethod
    def member_sync_list(self, business_id, is_check = False):
        """
        :description: 会员同步队列
        :param business_id: 商家标识
        :param is_check: is_check
        :return str
        :last_editors: HuangJianYi
        """
        prefix = "member_sync_list"
        if is_check == True:
            return f"{prefix}:check:businessid_{business_id}"
        return f"{prefix}:businessid_{business_id}"
    

    @classmethod
    def member_point_change_sync_list(self, business_id, is_check = False):
        """
        :description: 会员积分变更同步队列
        :param business_id: 商家标识
        :param is_check: is_check
        :return str
        :last_editors: HuangJianYi
        """
        prefix = "member_point_change_sync_list"
        if is_check == True:
            return f"{prefix}:check:businessid_{business_id}"
        return f"{prefix}:businessid_{business_id}"
    

    @classmethod
    def point_change_callback_list(self, business_id, is_check = False):
        """
        :description: 线下品牌积分变更消息回调API，告诉积分扣减或者累加是否成功。 
        :param business_id: 商家标识
        :param is_check: is_check
        :return str
        :last_editors: HuangJianYi
        """
        prefix = "point_change_callback_list"
        if is_check == True:
            return f"{prefix}:check:businessid_{business_id}"
        return f"{prefix}:businessid_{business_id}"
    
    
    @classmethod
    def member_info_update_list(self, business_id, is_check = False):
        """
        :description: 品牌会员入会时多店铺会员信息补充
        :param business_id: 商家标识
        :param is_check: is_check
        :return str
        :last_editors: HuangJianYi
        """
        prefix = "member_info_update_list"
        if is_check == True:
            return f"{prefix}:check:businessid_{business_id}"
        return f"{prefix}:businessid_{business_id}"
    


class CacheKey():
    """
    @description: 缓存key
    """
    @classmethod
    def cdp_work_info(self, work_name, store_id = None):
        """
        :description: CDP作业信息
        :param store_id: 店铺标识
        :param work_name: 作业名称(对应函数名)
        :return str
        :last_editors: HuangJianYi
        """
        dependency_key = f"cdp_work_info:workname_{work_name}"
        if store_id:
            dependency_key += f"_storeid_{store_id}"
        return dependency_key

    @classmethod
    def member_info(self, one_id):
        """
        :description: 会员信息
        :param one_id: one_id
        :return str
        :last_editors: HuangJianYi
        """
        dependency_key = f"member_info:oneid_{one_id}"
        return dependency_key

    @classmethod
    def user_info(self, ouid, plat_store_id):
        """
        :description: 用户信息
        :param ouid: ouid
        :param plat_store_id: 店铺ID
        :return str
        :last_editors: HuangJianYi
        """
        dependency_key = f"user_info:ouid_{ouid}_platstoreid_{plat_store_id}"
        return dependency_key
        


# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2024-12-13 11:45:32
@LastEditTime: 2025-01-13 15:49:22
@LastEditors: HuangJianYi
@Description: 
"""
from seven_cloudapp_frame.handlers.frame_base import *

from seven_cloudapp_frame.libs.customize.seven_helper import *


class TiktokSpiBaseHandler(FrameBaseHandler):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def response_json_success(self, data=None, desc='success'):
        """
        :Description: 通用成功返回json结构
        :param desc: 返回结果描述
        :param data: 返回结果对象，即为数组，字典
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        return self.response_common(0, desc, data, {"is_success": 1})

    def response_json_error(self, code=200007, desc='系统服务错误或者异常，请稍后重试', data=None):
        """
        :Description: 通用错误返回json结构
        :param desc: 错误描述
        :param data: 错误编码
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        return self.response_common(code, desc, data, {"is_success": 0})

    def response_json_error_params(self, desc='params error'):
        """
        :Description: 通用参数错误返回json结构
        :param desc: 返错误描述
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        return self.response_common(1, desc)

    def response_common(self, code, desc="", data=None, log_extra_dict=None):
        """
        :Description: 输出公共json模型
        :param code: 返回结果标识
        :param desc: 返回结果描述
        :param data: 返回结果对象，即为数组，字典
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        if hasattr(data, '__dict__'):
            data = data.__dict__

        rep_dic = {}
        rep_dic['code'] = code
        rep_dic['message'] = desc
        rep_dic['data'] = data

        return self.http_response(SevenHelper.json_dumps(rep_dic), log_extra_dict)

    def response_json_error_sign(self):
        """
        :Description: 签名验证失败错误返回json结构
        :param desc: 返错误描述
        :return: 将dumps后的数据字符串返回给客户端
        :last_editors: HuangJingCan
        """
        return self.response_common(100001, '签名验证失败', None, {"is_success": 0})


#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *

class CapBusinessInfoModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None, is_auto=False):
        super(CapBusinessInfoModel, self).__init__(CapBusinessInfo, sub_table)
        self.db = MySQLHelper(self.convert_db_config(db_connect_key, is_auto))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class CapBusinessInfo:

    def __init__(self):
        super(CapBusinessInfo, self).__init__()
        self.id = 0  # id
        self.guid = ""  # guid
        self.business_name = ""  # 商家名称
        self.phone = "" # 手机号
        self.business_desc = "" # 商家描述
        self.business_code = ""  # 商家代码
        self.product_ids = "" # 产品标识(逗号分隔)
        self.extend_info = {} # 扩展信息
        self.is_release = 0  # 是否发布(1-是 0-否)
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 修改时间

    @classmethod
    def get_field_list(self):
        return ['id', 'guid', 'business_name','phone', 'business_desc', 'business_code', 'product_ids', 'extend_info', 'is_release', 'create_date', 'modify_date']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "cap_business_info_tb"
